@@ -5,5 +5,5 @@ import dataclasses
 
 @dataclasses.dataclass(repr=True, frozen=True, kw_only=True, slots=True)
 class Info:
-    name: str | None = None
-    selectedTrack: int = -1
+    name: str
+    selectedTrack: int
